==> react-molecule-progress-steps-1.3.0.tgz: package/lib/components/MoleculeProgressStep/index.js <==
import React from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
var BASE_CLASS = "sui-MoleculeProgressSteps";
var CLASS_STEPS = BASE_CLASS + "-path";
var CLASS_BAR = CLASS_STEPS + "-bar";
var CLASS_STEP = CLASS_STEPS + "-step";
var CLASS_STEP_NUMBER = CLASS_STEP + "-number";
var CLASS_STEP_ICON = CLASS_STEP + "-icon";
var CLASS_STEP_DESCRIPTION = CLASS_STEP + "-description";
/* status */

var CLASS_BAR_VISITED = CLASS_BAR + "--visited";
var CLASS_STEP_ACTIVE = CLASS_STEP + "--active";
var CLASS_STEP_VISITED = CLASS_STEP + "--visited";
var STATUSES = {
  VISITED: 'VISITED',
  NORMAL: 'NORMAL',
  ACTIVE: 'ACTIVE'
};

var isVisited = function isVisited(status) {
  return status === STATUSES.VISITED;
};

var isActive = function isActive(status) {
  return status === STATUSES.ACTIVE;
};

var getStatusClass = function getStatusClass(status) {
  if (isVisited(status)) return [CLASS_STEP_VISITED, CLASS_BAR_VISITED];
  if (isActive(status)) return [CLASS_STEP_ACTIVE, ''];
  return ['', ''];
};

var MoleculeProgressStep = function MoleculeProgressStep(_ref) {
  var status = _ref.status,
      icon = _ref.icon,
      label = _ref.label,
      numStep = _ref.numStep,
      lastStep = _ref.lastStep,
      compressed = _ref.compressed;

  var _getStatusClass = getStatusClass(status),
      CLASS_STEP_STATUS = _getStatusClass[0],
      CLASS_BAR_STATUS = _getStatusClass[1];

  var bar = /*#__PURE__*/React.createElement("hr", {
    className: cx(CLASS_BAR, CLASS_BAR_STATUS)
  });
  return /*#__PURE__*/React.createElement(React.Fragment, null, !compressed && /*#__PURE__*/React.createElement("div", {
    className: cx(CLASS_STEP, CLASS_STEP_STATUS)
  }, icon ? /*#__PURE__*/React.createElement("div", {
    className: CLASS_STEP_ICON
  }, icon) : /*#__PURE__*/React.createElement("p", {
    className: CLASS_STEP_NUMBER
  }, numStep), /*#__PURE__*/React.createElement("p", {
    className: CLASS_STEP_DESCRIPTION
  }, label)), !lastStep ? bar : compressed && bar);
};

export default MoleculeProgressStep;
export { STATUSES };

==> react-molecule-progress-steps-1.4.0.tgz: package/lib/components/MoleculeProgressStep/index.js <==
import { jsxs as _jsxs } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsx as _jsx } from "react/jsx-runtime";
import cx from 'classnames';
var BASE_CLASS = "sui-MoleculeProgressSteps";
var CLASS_STEPS = BASE_CLASS + "-path";
var CLASS_BAR = CLASS_STEPS + "-bar";
var CLASS_STEP = CLASS_STEPS + "-step";
var CLASS_STEP_NUMBER = CLASS_STEP + "-number";
var CLASS_STEP_ICON = CLASS_STEP + "-icon";
var CLASS_STEP_DESCRIPTION = CLASS_STEP + "-description";
/* status */

var CLASS_BAR_VISITED = CLASS_BAR + "--visited";
var CLASS_STEP_ACTIVE = CLASS_STEP + "--active";
var CLASS_STEP_VISITED = CLASS_STEP + "--visited";
var STATUSES = {
  VISITED: 'VISITED',
  NORMAL: 'NORMAL',
  ACTIVE: 'ACTIVE'
};

var isVisited = function isVisited(status) {
  return status === STATUSES.VISITED;
};

var isActive = function isActive(status) {
  return status === STATUSES.ACTIVE;
};

var getStatusClass = function getStatusClass(status) {
  if (isVisited(status)) return [CLASS_STEP_VISITED, CLASS_BAR_VISITED];
  if (isActive(status)) return [CLASS_STEP_ACTIVE, ''];
  return ['', ''];
};

var MoleculeProgressStep = function MoleculeProgressStep(_ref) {
  var status = _ref.status,
      icon = _ref.icon,
      label = _ref.label,
      numStep = _ref.numStep,
      lastStep = _ref.lastStep,
      compressed = _ref.compressed;

  var _getStatusClass = getStatusClass(status),
      CLASS_STEP_STATUS = _getStatusClass[0],
      CLASS_BAR_STATUS = _getStatusClass[1];

  var bar = /*#__PURE__*/_jsx("hr", {
    className: cx(CLASS_BAR, CLASS_BAR_STATUS)
  });

  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [!compressed && /*#__PURE__*/_jsxs("div", {
      className: cx(CLASS_STEP, CLASS_STEP_STATUS),
      children: [icon ? /*#__PURE__*/_jsx("div", {
        className: CLASS_STEP_ICON,
        children: icon
      }) : /*#__PURE__*/_jsx("p", {
        className: CLASS_STEP_NUMBER,
        children: numStep
      }), /*#__PURE__*/_jsx("p", {
        className: CLASS_STEP_DESCRIPTION,
        children: label
      })]
    }), !lastStep ? bar : compressed && bar]
  });
};

export default MoleculeProgressStep;
export { STATUSES };
